@@ -39,6 +39,14 @@ my %_char_lists = (
         # 0x7X:
         0x23BB, 0x2500, 0x23BC, 0x23BD, 0x251C, 0x2524, 0x2534, 0x252C, 0x2502, 0x2264, 0x2265, 0x03C0, 0x2260, 0x00A3, 0x00B7,
     ],
+    'dec-tech' => [
+        0x0020, 0x00AC, 0x00D7, 0x00F7, 0x0192, 0x0393, 0x0394, 0x0398, 0x039B, 0x039E, 0x03A0, 0x03A3, 0x03A5, 0x03A6, 0x03A8, 0x03A9,
+        0x03B1, 0x03B2, 0x03B3, 0x03B4, 0x03B5, 0x03B6, 0x03B7, 0x03B8, 0x03B9, 0x03BA, 0x03BB, 0x03BD, 0x03BE, 0x03C0, 0x03C1, 0x03C3,
+        0x03C4, 0x03C5, 0x03C6, 0x03C7, 0x03C8, 0x03C9, 0x2190, 0x2191, 0x2192, 0x2193, 0x21D2, 0x21D4, 0x2202, 0x2207, 0x221A, 0x221D,
+        0x221E, 0x2227, 0x2228, 0x2229, 0x222A, 0x222B, 0x2234, 0x223C, 0x2243, 0x2260, 0x2261, 0x2264, 0x2265, 0x2282, 0x2283, 0x231D,
+        0x231F, 0x2320, 0x2321, 0x239B, 0x239D, 0x239E, 0x23A0, 0x23A1, 0x23A3, 0x23A4, 0x23A6, 0x23A8, 0x23AC, 0x23B2, 0x23B3, 0x23B7,
+        0x2500, 0x2502, 0x250C, 0x2571, 0x2572, 0x27E9,
+    ],
     'sirtx-characters' => [
         0x20AC, 0x2191, 0x2193, 0x2190,  0x2192,  0x221E, 0x2261, 0x25C4, 0x25BA, 0x2642, 0x2640, 0x263A, 0x263B, 0x2665, 0x2660, 0x2663,
         0x266A, 0x23A1, 0x23A6, 0x1F431, 0x1FBB0, 0x2026, 0x03A9, 0x231B, 0x00A4,
@@ -98,20 +106,78 @@ $_default_alias_lists{'common-small'} = {
 };
 $_default_alias_lists{'common-large'} = {
     %{$_default_alias_lists{'common-small'}},
-    0x00B5 => 0x03BC, # MICRO SIGN          -> GREEK SMALL LETTER MU
-    0x037E => 0x003B, # GREEK QUESTION MARK -> SEMICOLON
-    0x0387 => 0x00B7, # GREEK ANO TELEIA    -> MIDDLE DOT
-    0x2024 => 0x002E, # ONE DOT LEADER      -> FULL STOP
-    0x2126 => 0x03A9, # OHM SIGN            -> GREEK CAPITAL LETTER OMEGA
-    0x212B => 0x00C5, # ANGSTROM SIGN       -> LATIN CAPITAL LETTER A WITH RING ABOVE
-    0x2236 => 0x003A, # RATIO               -> COLON
+    0x00B5 => 0x03BC,   # MICRO SIGN                    -> GREEK SMALL LETTER MU
+    0x037E => 0x003B,   # GREEK QUESTION MARK           -> SEMICOLON
+    0x0387 => 0x00B7,   # GREEK ANO TELEIA              -> MIDDLE DOT
+    0x2024 => 0x002E,   # ONE DOT LEADER                -> FULL STOP
+    0x2126 => 0x03A9,   # OHM SIGN                      -> GREEK CAPITAL LETTER OMEGA
+    0x212B => 0x00C5,   # ANGSTROM SIGN                 -> LATIN CAPITAL LETTER A WITH RING ABOVE
+    0x2236 => 0x003A,   # RATIO                         -> COLON
+    0x2666 => 0x25C6,   # BLACK DIAMOND SUIT            -> BLACK DIAMOND
+    0x2665 => 0x1F5A4,  # BLACK HEART SUIT              -> BLACK HEART
+    0x220E => 0x25A0,   # END OF PROOF                  -> BLACK SQUARE
+    0x223C => 0x007E,   # TILDE OPERATOR                -> TILDE
+
+    # Roman numbers:
+    0x2160 => 0x0049,   # ROMAN NUMERAL ONE             -> LATIN CAPITAL LETTER I
+    0x2164 => 0x0056,   # ROMAN NUMERAL FIVE            -> LATIN CAPITAL LETTER V
+    0x2169 => 0x0058,   # ROMAN NUMERAL TEN             -> LATIN CAPITAL LETTER X
+    0x216C => 0x004C,   # ROMAN NUMERAL FIFTY           -> LATIN CAPITAL LETTER L
+    0x216D => 0x0043,   # ROMAN NUMERAL ONE HUNDRED     -> LATIN CAPITAL LETTER C
+    0x216E => 0x0044,   # ROMAN NUMERAL FIVE HUNDRED    -> LATIN CAPITAL LETTER D
+    0x216F => 0x004D,   # ROMAN NUMERAL ONE THOUSAND    -> LATIN CAPITAL LETTER M
+
+    0x2170 => 0x0069,   # SMALL ROMAN NUMERAL ONE           -> LATIN SMALL LETTER I
+    0x2174 => 0x0076,   # SMALL ROMAN NUMERAL FIVE          -> LATIN SMALL LETTER V
+    0x2179 => 0x0078,   # SMALL ROMAN NUMERAL TEN           -> LATIN SMALL LETTER X
+    0x217C => 0x006C,   # SMALL ROMAN NUMERAL FIFTY         -> LATIN SMALL LETTER L
+    0x217D => 0x0063,   # SMALL ROMAN NUMERAL ONE HUNDRED   -> LATIN SMALL LETTER C
+    0x217E => 0x0064,   # SMALL ROMAN NUMERAL FIVE HUNDRED  -> LATIN SMALL LETTER D
+    0x217F => 0x006D,   # SMALL ROMAN NUMERAL ONE THOUSAND  -> LATIN SMALL LETTER M
+
+    # gr_la_ru
+    0x0391 => 0x0041,   # GREEK CAPITAL LETTER ALPHA    -> LATIN CAPITAL LETTER A
+    0x0392 => 0x0042,   # GREEK CAPITAL LETTER BETA     -> LATIN CAPITAL LETTER B
+    0x0395 => 0x0045,   # GREEK CAPITAL LETTER EPSILON  -> LATIN CAPITAL LETTER E
+    0x03A1 => 0x0050,   # GREEK CAPITAL LETTER RHO      -> LATIN CAPITAL LETTER P
+    0x0397 => 0x0048,   # GREEK CAPITAL LETTER ETA      -> LATIN CAPITAL LETTER H
+    0x03A4 => 0x0054,   # GREEK CAPITAL LETTER TAU      -> LATIN CAPITAL LETTER T
+    0x039A => 0x004B,   # GREEK CAPITAL LETTER KAPPA    -> LATIN CAPITAL LETTER K
+    0x039C => 0x004D,   # GREEK CAPITAL LETTER MU       -> LATIN CAPITAL LETTER M
+    0x039F => 0x004F,   # GREEK CAPITAL LETTER OMICRON  -> LATIN CAPITAL LETTER O
+    0x03A7 => 0x0058,   # GREEK CAPITAL LETTER CHI      -> LATIN CAPITAL LETTER X
+    0x03A5 => 0x0059,   # GREEK CAPITAL LETTER UPSILON  -> LATIN CAPITAL LETTER Y
+
+    0x0410 => 0x0041,   # CYRILLIC CAPITAL LETTER A     -> LATIN CAPITAL LETTER A
+    0x0412 => 0x0042,   # CYRILLIC CAPITAL LETTER VE    -> LATIN CAPITAL LETTER B
+    0x0415 => 0x0045,   # CYRILLIC CAPITAL LETTER IE    -> LATIN CAPITAL LETTER E
+    0x0420 => 0x0050,   # CYRILLIC CAPITAL LETTER ER    -> LATIN CAPITAL LETTER P
+    0x041D => 0x0048,   # CYRILLIC CAPITAL LETTER EN    -> LATIN CAPITAL LETTER H
+    0x0422 => 0x0054,   # CYRILLIC CAPITAL LETTER TE    -> LATIN CAPITAL LETTER T
+    0x041A => 0x004B,   # CYRILLIC CAPITAL LETTER KA    -> LATIN CAPITAL LETTER K
+    0x041C => 0x004D,   # CYRILLIC CAPITAL LETTER EM    -> LATIN CAPITAL LETTER M
+    0x041E => 0x004F,   # CYRILLIC CAPITAL LETTER O     -> LATIN CAPITAL LETTER O
+    0x0425 => 0x0058,   # CYRILLIC CAPITAL LETTER HA    -> LATIN CAPITAL LETTER X
+    0x0423 => 0x0059,   # CYRILLIC CAPITAL LETTER U     -> LATIN CAPITAL LETTER Y
+
+    # gr_la
+    0x039D => 0x004E,   # GREEK CAPITAL LETTER NU       -> LATIN CAPITAL LETTER N
+    0x0396 => 0x005A,   # GREEK CAPITAL LETTER ZETA     -> LATIN CAPITAL LETTER Z
+    0x0399 => 0x0049,   # GREEK CAPITAL LETTER IOTA     -> LATIN CAPITAL LETTER I
+    0x03B2 => 0x00DF,   # GREEK SMALL LETTER BETA       -> LATIN SMALL LETTER SHARP S
+    0x03BF => 0x006F,   # GREEK SMALL LETTER OMICRON    -> LATIN SMALL LETTER O
+    0x03AA => 0x00CF,   # GREEK CAPITAL LETTER IOTA WITH DIALYTIKA      -> LATIN CAPITAL LETTER I WITH DIAERESIS
+    0x03AB => 0x0178,   # GREEK CAPITAL LETTER UPSILON WITH DIALYTIKA   -> LATIN CAPITAL LETTER Y WITH DIAERESIS
+
+    # la_ru
+    0x0421 => 0x0043,   # CYRILLIC CAPITAL LETTER ES    -> LATIN CAPITAL LETTER C
 };
 $_default_alias_lists{'common-all'} = {
     %{$_default_alias_lists{'common-large'}},
     0x00A0 => 0x0020, # NO-BREAK SPACE      -> SPACE
 };
 
-our $VERSION = v0.02;
+our $VERSION = v0.03;
 
 
 
@@ -526,12 +592,43 @@ sub export_glyph_as_image_magick {
         croak 'Unsupported glyph size';
     }
 
+    require Image::Magick;
     $p = Image::Magick->new(magick => 'wbmp');
     $p->BlobToImage(pack('CCCC', 0, 0, $self->width, $self->height).$glyph);
 
     return $p;
 }
 
+
+sub render {
+    require List::Util;
+    require Image::Magick;
+
+    my ($self, $string) = @_;
+    my @lines = split(/\r?\n/, $string);
+    my $max_line = List::Util::max(map {length} @lines);
+    my $width = $self->width;
+    my $height = $self->height;
+    my $p = Image::Magick->new;
+    my %handle_cache;
+
+    $p->Set(size => sprintf('%ux%u', $max_line * $width, scalar(@lines) * $height));
+    $p->Read('canvas:white');
+
+    for (my $row = 0; $row < scalar(@lines); $row++) {
+        my $line = $lines[$row];
+        my $len  = length($line);
+
+        for (my $column = 0; $column < $len; $column++) {
+            my $c = substr($line, $column, 1);
+            my $handle = $handle_cache{ord $c} //= $self->export_glyph_as_image_magick($self->glyph_for(ord $c));
+            $p->CopyPixels(image => $handle, width => $width, height => $height, x => 0, y => 0, dx => $column * $width, dy => $row * $height);
+        }
+    }
+
+    return $p;
+}
+
 1;
 
 __END__
@@ -546,7 +643,7 @@ SIRTX::Font - module for working with SIRTX font files
 
 =head1 VERSION
 
-version v0.02
+version v0.03
 
 =head1 SYNOPSIS
 
@@ -588,6 +685,10 @@ All printable characters in DEC-MCS (Multinational Character Set).
 
 All printable characters in DEC-SG (Special Graphics).
 
+=item C<dec-tech>
+
+All printable characters in DEC Technical.
+
 =item C<sirtx-characters>
 
 All characters in the SIRTX character list (provided by SIRTX on old non-Unicode terminals that support DLLCS).
@@ -844,6 +945,18 @@ In order to deduplicate entries a call to L</gc> might be considered.
 
 Exports a single glyph as a image object.
 
+=head2 render
+
+    my Image::Magick $image = $font->render($string);
+    # e.g.:
+    my Image::Magick $image = $font->render("Hello World!");
+    $image->Transparent(color => 'white'); # transparent background
+    $image->Write('hello.png');
+
+(experimental)
+
+Renders a text using the loaded font.
+
 =head1 AUTHOR
 
 Löwenfelsen UG (haftungsbeschränkt) <support@loewenfelsen.net>
